############################
Using the GEMINI API
############################

.. automodule:: gemini

The GeminiQuery class
=====================
.. autoclass:: GeminiQuery
   :members: run, header, sample2index, index2sample
   :undoc-members:
